==> pait-0.6.1-py3-none-any.whl: pait/app/sanic/_pait.py <==
from typing import Callable, Dict, List, Optional, Tuple, Type

from sanic.response import HTTPResponse, json
from sanic_testing.testing import SanicTestClient, TestingResponse  # type: ignore

from pait.core import pait as _pait
from pait.model.response import PaitResponseModel
from pait.model.status import PaitStatus
from pait.util import gen_example_json_from_schema

from ._app_helper import AppHelper

__all__ = ["pait"]


def make_mock_response(pait_response: Type[PaitResponseModel]) -> HTTPResponse:
    if pait_response.media_type == "application/json" and pait_response.response_data:
        resp: HTTPResponse = json(gen_example_json_from_schema(pait_response.response_data.schema()))
        resp.status = pait_response.status_code[0]
        if pait_response.header:
            resp.headers.update(pait_response.header)
        return resp
    else:
        raise NotImplementedError()


def pait(
    # param check
    at_most_one_of_list: Optional[List[List[str]]] = None,
    required_by: Optional[Dict[str, List[str]]] = None,
    # doc
    author: Optional[Tuple[str]] = None,
    desc: Optional[str] = None,
    summary: Optional[str] = None,
    name: Optional[str] = None,
    status: Optional[PaitStatus] = None,
    group: Optional[str] = None,
    tag: Optional[Tuple[str, ...]] = None,
    response_model_list: Optional[List[Type[PaitResponseModel]]] = None,
) -> Callable:
    """Help starlette provide parameter checks and type conversions for each routing function/cbv class"""
    return _pait(
        AppHelper,
        make_mock_response_fn=make_mock_response,
        author=author,
        desc=desc,
        summary=summary,
        name=name,
        status=status,
        group=group,
        tag=tag,
        response_model_list=response_model_list,
        at_most_one_of_list=at_most_one_of_list,
        required_by=required_by,
    )

==> pait-0.6.2.3-py3-none-any.whl: pait/app/sanic/_pait.py <==
import json
from typing import Callable, Dict, List, Optional, Tuple, Type

from sanic.response import HTTPResponse
from sanic.response import json as resp_json
from sanic_testing.testing import SanicTestClient, TestingResponse  # type: ignore

from pait.core import pait as _pait
from pait.model.response import PaitResponseModel
from pait.model.status import PaitStatus
from pait.util import gen_example_json_from_schema

from ._app_helper import AppHelper

__all__ = ["pait"]


def make_mock_response(pait_response: Type[PaitResponseModel]) -> HTTPResponse:
    if pait_response.media_type == "application/json" and pait_response.response_data:
        resp: HTTPResponse = resp_json(
            json.loads(gen_example_json_from_schema(pait_response.response_data.schema(), use_example_value=True))
        )
        resp.status = pait_response.status_code[0]
        if pait_response.header:
            resp.headers.update(pait_response.header)
        return resp
    else:
        raise NotImplementedError()


def pait(
    # param check
    at_most_one_of_list: Optional[List[List[str]]] = None,
    required_by: Optional[Dict[str, List[str]]] = None,
    # doc
    author: Optional[Tuple[str]] = None,
    desc: Optional[str] = None,
    summary: Optional[str] = None,
    name: Optional[str] = None,
    status: Optional[PaitStatus] = None,
    group: Optional[str] = None,
    tag: Optional[Tuple[str, ...]] = None,
    response_model_list: Optional[List[Type[PaitResponseModel]]] = None,
) -> Callable:
    """Help starlette provide parameter checks and type conversions for each routing function/cbv class"""
    return _pait(
        AppHelper,
        make_mock_response_fn=make_mock_response,
        author=author,
        desc=desc,
        summary=summary,
        name=name,
        status=status,
        group=group,
        tag=tag,
        response_model_list=response_model_list,
        at_most_one_of_list=at_most_one_of_list,
        required_by=required_by,
    )
